FocusedMenuItem class

Constructors

FocusedMenuItem({Color? backgroundColor, required Widget title, Icon? trailingIcon, required Function onPressed})

Properties

backgroundColor ↔ Color?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
onPressed ↔ Function
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ Widget
getter/setter pair
trailingIcon ↔ Icon?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited